@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2012, 2013 Red Hat, Inc.
+ * Copyright (c) 2011, 2012, 2013, 2014 Red Hat, Inc.
  *
  * Gnome Documents is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -354,6 +354,14 @@ const DocCommon = new Lang.Class({
         }
     },
 
+    canShare: function(callback) {
+        log('Error: DocCommon implementations must override canShare');
+    },
+
+    canTrash: function(callback) {
+        log('Error: DocCommon implementations must override canTrash');
+    },
+
     createThumbnail: function(callback) {
         log('Error: DocCommon implementations must override createThumbnail');
     },
@@ -546,7 +554,7 @@ const DocCommon = new Lang.Class({
             this._collectionIconWatcher = null;
         }
 
-        Application.settings.disconnect(this._refreshIconId);
+        Application.application.disconnect(this._refreshIconId);
         Application.searchCategoryManager.disconnect(this._filterId);
     },
 
@@ -678,6 +686,10 @@ const LocalDocument = new Lang.Class({
             }));
     },
 
+    canShare: function() {
+        return false;
+    },
+
     canTrash: function() {
         return this.collection;
     },
@@ -841,6 +853,10 @@ const GoogleDocument = new Lang.Class({
         this.parent(cursor);
     },
 
+    canShare: function() {
+        return true;
+    },
+
     canTrash: function() {
         return false;
     }
@@ -897,6 +913,10 @@ const OwncloudDocument = new Lang.Class({
             }));
     },
 
+    canShare: function() {
+        return false;
+    },
+
     canTrash: function() {
         return false;
     }
@@ -989,6 +1009,10 @@ const SkydriveDocument = new Lang.Class({
         this.typeDescription = description;
     },
 
+    canShare: function() {
+        return false;
+    },
+
     canTrash: function() {
         return false;
     }
