@@ -69,8 +69,8 @@ const PropertiesDialog = new Lang.Class({
                                    row_spacing: 6,
                                    column_spacing: 24,
                                    margin_top: 12,
-                                   margin_left: 24,
-                                   margin_right: 24,
+                                   margin_start: 24,
+                                   margin_end: 24,
                                    margin_bottom: 12 });
 
         let contentArea = this.widget.get_content_area();
